/**###########################################################################
##                                                                          ##
## JQuickPlot - Java Quick XY Plots                                         ##
##                                                                          ##
## Copyright (C) 2008  Frederic Roudaut  <frederic.roudaut@free.fr>         ##
##                                                                          ##
##                                                                          ##
## This program is free software; you can redistribute it and/or modify it  ##
## under the terms of the GNU General Public License version 2 as           ##
## published by the Free Software Foundation; version 2.                    ##
##                                                                          ##
## This program is distributed in the hope that it will be useful, but      ##
## WITHOUT ANY WARRANTY; without even the implied warranty of               ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU        ##
## General Public License for more details.                                 ##
##                                                                          ##
############################################################################**/

package JQuickPlot;

import java.lang.String;
import java.util.ArrayList;
import java.util.List;

/**
 * Represent a column selection for a dots file 
 *
 */
public class Column {

    /** column Num **/
    private int _column = -1;

    /** column title to display in the legend **/
    private String _title = "";
    
    /**
     * Constructor
     *
     * @param column  column Num 
     * @param title  column title to display in the legend
     */  
    Column (int column, String title)
    {
	column =  _column;
	title = _title;
    }

    /**
     * Constructor
     *
     * @param column  column Num 
     */     
    Column (int column)
    {
	_column =  column;
	_title = "";
    }

    /**
     * Default Constructor
     *
     */     
    Column ()
    {
	_column =  -1;
	_title = "";
    }

    /**
     * return the column num
     *
     */     
    public int getColumn()
    {
	return _column;
    }

    /**
     * return the title
     *
     */         
    public String getTitle()
    {
	return _title;
    }	

    /**
     * check is there is a title not equals to ""
     *
     */            
    public boolean isTitleEmpty()
    {
	return _title.equals("");
    }	

    /**
     * check is the column num is valid
     *
     */                
    public boolean isValid ()
    {
	return (_column > -1);
    }
    
    /**
     * Display the object
     *
     */                
    public void display ()
    {
	System.out.println("Column : <" + _column + ">\tTitle : <" + _title + ">"); 
    }


    /**
     * parse a string and return a Column object
     *
     * @param str the string to parse (use the form columnNum:title)
     */                
    public static Column parse (String str)
    {
	Column res = new Column();	
	
	String colList[] = str.split(":");		    
	try
	    {
		res._column = Integer.valueOf(colList[0]).intValue();	    
	    }
	catch(Exception e)
	    {
		res._column = -1;
	    }


	if(colList.length > 1)
	    {
		res._title = colList[1];
	    }


	return res;
    }
}
