/**###########################################################################
##                                                                          ##
## JQuickPlot - Java Quick XY Plots                                         ##
##                                                                          ##
## Copyright (C) 2008  Frederic Roudaut  <frederic.roudaut@free.fr>         ##
##                                                                          ##
##                                                                          ##
## This program is free software; you can redistribute it and/or modify it  ##
## under the terms of the GNU General Public License version 2 as           ##
## published by the Free Software Foundation; version 2.                    ##
##                                                                          ##
## This program is distributed in the hope that it will be useful, but      ##
## WITHOUT ANY WARRANTY; without even the implied warranty of               ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU        ##
## General Public License for more details.                                 ##
##                                                                          ##
############################################################################**/

package JQuickPlot;

import java.lang.String;
import java.util.ArrayList;
import java.util.List;


/**

 * Represent a column List selection for a dots file 
 *
 */
public class ColumnList {
    
    /** A List of Columns **/
    private List _columnList;

    /**
     * Default Constructor
     *
     */     
    public ColumnList()
    {
	_columnList = new ArrayList();
    }

    /**
     * Add a Column
     *
     * @param column column Num 
     * @param title  column title to display in the legend
     */  
    public boolean addColumn(int column, String title)
    {
	return _columnList.add(new Column(column, title));	
    }

    /**
     * Add a Column
     *
     * @param column column Num 
     */      
    public boolean addColumn(int column)
    {
	return _columnList.add(new Column(column));	
    }

    /**
     * Add a Column
     *
     * @param column Column object to add
     */      
    public boolean add(Column column)
    {
	return _columnList.add(column);	
    }

    /**
     * get a column object from its position
     *
     * @param pos position in the Columns List
     */          
    public Column get(int pos)
    {
	return (Column) _columnList.get(pos);	
    }

    /**
     * get the size of the Columns List
     *
     */          
    public int size()
    {
	return _columnList.size();
    }

    /**
     * check if the the Columns List is empty
     *
     */          
    public boolean isEmpty() 
    {
	return _columnList.isEmpty();
    }

    /**
     * parse a string and return a Column List object
     *
     * @param str the string to parse (use the form columnNum:title;columnNum:title ... )
     */                
    public static ColumnList parse (String str)
    {
	String colList[] = str.split(";");		    

	ColumnList res = new ColumnList();
	for (int i=0; i < colList.length; i++)
	    {
		Column col = Column.parse(colList[i]);
		if(col.isValid()) 
		    res.add(col);		
	    }

	return res;
    }

    /**
     * Display the object
     *
     */                
    public void display ()
    {

	for (int i=0; i < size(); i++)
	    {	
		get(i).display();
	    }	    
	
    }

    /**
     * Main for test purpose
     *
     */                
    public static void main(String args[])
    {

	System.out.println("\ncl1");
	ColumnList cl1 = ColumnList.parse("1:column1;2:column2");
	cl1.display();

	System.out.println("\ncl2");
	ColumnList cl2 = ColumnList.parse("1:column1;");
	cl2.display();

	System.out.println("\ncl3");
	ColumnList cl3 = ColumnList.parse("1:;");
	cl3.display();

	System.out.println("\ncl4");
	ColumnList cl4 = ColumnList.parse("1;");
	cl4.display();

	System.out.println("\ncl5");
	ColumnList cl5 = ColumnList.parse("1:");
	cl5.display();

	System.out.println("\ncl6");
	ColumnList cl6 = ColumnList.parse("1:");
	cl6.display();

	System.out.println("\ncl7");
	ColumnList cl7 = ColumnList.parse(":");
	cl7.display();

	System.out.println("\ncl8");
	ColumnList cl8 = ColumnList.parse(";");
	cl8.display();

	System.out.println("\ncl9");
	ColumnList cl9 = ColumnList.parse("");
	cl9.display();

	System.out.println("\ncl10");
	ColumnList cl10 = ColumnList.parse(";:");
	cl10.display();

	System.out.println("\ncl11");
	ColumnList cl11 = ColumnList.parse(":rrrr");
	cl11.display();

    }
			

}


