/**###########################################################################
##                                                                          ##
## JQuickPlot - Java Quick XY Plots                                         ##
##                                                                          ##
## Copyright (C) 2008  Frederic Roudaut  <frederic.roudaut@free.fr>         ##
##                                                                          ##
##                                                                          ##
## This program is free software; you can redistribute it and/or modify it  ##
## under the terms of the GNU General Public License version 2 as           ##
## published by the Free Software Foundation; version 2.                    ##
##                                                                          ##
## This program is distributed in the hope that it will be useful, but      ##
## WITHOUT ANY WARRANTY; without even the implied warranty of               ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU        ##
## General Public License for more details.                                 ##
##                                                                          ##
############################################################################**/

package JQuickPlot;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.Point;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import org.jdesktop.layout.GroupLayout;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JFrame;
import javax.swing.JTabbedPane;
import javax.swing.BoxLayout;
import javax.swing.SwingConstants;

import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.DateAxis;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.ValueAxis;
import org.jfree.chart.plot.CombinedDomainXYPlot;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.xy.StandardXYItemRenderer;
import org.jfree.chart.renderer.xy.*;
import org.jfree.data.xy.XYSeriesCollection;
import org.jfree.data.xy.XYSeries;
import org.jfree.ui.ApplicationFrame;
import org.jfree.ui.RefineryUtilities;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.FileInputStream;
import java.io.BufferedReader;
import java.lang.System;

import java.util.HashMap;


/**
 * The Main Class for JQuickPlot
 *
 */
public class  JQuickPlot extends ApplicationFrame implements ActionListener {

    /** The number of subplots per plots. **/
    private int _nbSubplots = 0;  

    /** The number of plots **/
    private int _nbPlots = 16;  

    /** Datasets List for plots **/
    private XYSeriesCollection[] _datasets;    

    /** Columns List for X in plots **/
    private ColumnList[] datasetColumnListX;

    /** Columns List for Y in plots **/
    private ColumnList[] datasetColumnListY;

    /** Files List for Datasets of plots **/
    private String[] _datasetFile;

    /** X Label for Datasets of plots **/
    private String[] _labelX;

    /** Y Label for Datasets of plots **/
    private String[] _labelY;

    /** plots List **/
    private CombinedDomainXYPlot[] _plotList;

    /** subplots List per plot **/
    private XYPlot[][] _subplotList;
    
    /* Renderer Constants */
    /**
       Standard renderer for the XYPlot class.
    **/
    public static final int ConstStandardXYItemRenderer = 0;

    /**
       Standard renderer for the XYPlot class with dots.
    **/
    public static final int ConstDefaultXYItemRenderer = 1;

    /**
       A XYLineAndShapeRenderer that adds a shadow line to the graph to emulate a 3D-effect.
    **/
    public static final int ConstXYLine3DRenderer = 2;

    /**
       A Spline Renderer.
    **/
    public static final int ConstXYSplineRenderer = 3;

    /**
       A renderer that draws a line connecting the start and end Y values for an XYPlot .
    **/
    public static final int ConstYIntervalRenderer = 4;

    /**
       A renderer for an XYPlot that highlights the differences between two series. The renderer expects a dataset that:<br/>
       - has exactly two series;<br/>
       - each series has the same x-values;<br/>
       - no null values; 
    **/
    public static final int ConstXYDifferenceRenderer = 5;

    /**
       A renderer that draws a small dot at each data point for an XYPlot .
    **/
    public static final int ConstXYDotRenderer = 6;

    public static final int ConstXYErrorRenderer = 7;
    public static final int ConstVectorRenderer = 8;
    public static final int ConstDeviationRenderer = 9;

    /**
       The Cyclic XY item renderer is specially designed to handle cyclic axis. While the standard renderer would
       draw a line across the plot when a cycling occurs, the cyclic renderer splits the line at each cycle end instead.
       This is done by interpolating new points at cycle boundary. Thus, correct appearance is restored. 
       The Cyclic XY item renderer works exactly like a standard XY item renderer with non-cyclic axis.
    **/
    public static final int ConstCyclicXYItemRenderer = 10;

    /**
       An extension of XYBarRenderer that displays bars for different series values at the same x next 
       to each other. The assumption here is that for each x (time or else) there is a y value for each 
       series. If this is not the case, there will be spaces between bars for a given x.
       This renderer does not include code to calculate the crosshair point for the plot.
    **/    
    public static final int ConstClusteredXYBarRenderer = 11;

    /**
       Area item renderer for an XYPlot . This class can draw (a) shapes at each point, or (b) 
       lines between points, or (c) both shapes and lines, or (d) filled areas, or (e) filled areas and shapes.
    **/    
    public static final int ConstXYAreaRenderer = 12;

    /** 
	Area item renderer for an XYPlot .
    **/    
    public static final int ConstXYAreaRenderer2 = 13;

    /**
       Line/Step item renderer for an XYPlot . This class draws lines between data points, only allowing horizontal or 
       vertical lines (steps).
    **/    
    public static final int ConstXYStepRenderer = 14;

    /**
       A step chart renderer that fills the area between the step and the x-axis.
    **/		    
    public static final int ConstXYStepAreaRenderer = 15;
    	
    /** Indicate if the Configuration Menu is visible **/
    private boolean _ConfMenuIsOpened = false;

    /** Configuration Menu Window **/
    private final JFrame _frameConfiguration = new JFrame("[=] Configuration Menu [=]");

    /**
     * Display Usage when running the main.
     *
     */        
    public static void usage () 
    {
	System.out.println("\nUSAGE : < NbGraphs (integer) > < Title (string) >");
	System.out.println("\nwith <NbGraphs> : Graphs number (One Graph may contains several plots)");
	System.out.println("     <Title>    : Main title");
    }
	
    /**
     * Constructor
     *
     * @param nbSubplots : subplots Number (ie Graphs number per plot)
     * @param title : Main title to display
     */        
    public JQuickPlot(final int nbSubplots, final String title) {
	
        super(title);
	
	_nbSubplots = nbSubplots;
	_labelX = new String[1];	
	_labelX[0]="X";
	_labelY = new String[_nbSubplots];
	datasetColumnListX = new ColumnList[_nbSubplots];
	datasetColumnListY = new ColumnList[_nbSubplots];
	_subplotList = new XYPlot[_nbPlots][_nbSubplots];
	_datasetFile = new String[_nbSubplots];

	for (int i = 0; i < _nbSubplots; i++)
	    {
		datasetColumnListX[i] = new ColumnList();
		datasetColumnListY[i] = new ColumnList();
		_datasetFile[i] = "";
		_labelY[i] = new String();
	    }

	initConfMenu();
	
	this._datasets = new XYSeriesCollection[_nbSubplots];

	for (int i = 0; i < _nbSubplots; i++) 
	    {		
		this._datasets[i] = new XYSeriesCollection();
	    }

	final JPanel content = new JPanel(new BorderLayout());		
	JTabbedPane onglets = new JTabbedPane(SwingConstants.TOP);

	_plotList = new CombinedDomainXYPlot[_nbPlots];

	for(int i = 0; i< _nbPlots; i++)
	    {
		CombinedDomainXYPlot plot = createPlot(i); 	
		final JFreeChart chart = new JFreeChart(title, plot);
		chart.setBorderPaint(Color.black);
		chart.setBorderVisible(true);
		chart.setBackgroundPaint(Color.white);
            
		final ChartPanel chartPanel = new ChartPanel(chart);
		chartPanel.setPreferredSize(new java.awt.Dimension(500, 470));
		chartPanel.setBorder(BorderFactory.createEmptyBorder(8, 8, 8, 8));
		
		if(i==ConstDefaultXYItemRenderer)
		    {
			onglets.add("Standard2",chartPanel) ;
		    }			
		else if(i==ConstXYLine3DRenderer)
		    {
			onglets.add("Line3D",chartPanel) ;
		    }
		else if(i==ConstXYSplineRenderer)
		    {
			onglets.add("Spline",chartPanel) ;
		    }
		else if(i==ConstYIntervalRenderer)
		    {
			onglets.add("YInterval",chartPanel) ;
		    }
		else if(i==ConstXYDifferenceRenderer)
		    {
			onglets.add("Difference",chartPanel) ;
		    }
		else if(i==ConstXYDotRenderer)
		    {
			onglets.add("Dot",chartPanel) ;
		    }
		else if(i==ConstXYErrorRenderer)
		    {
			onglets.add("Error",chartPanel) ;
		    }
		else if(i==ConstVectorRenderer)
		    {
			onglets.add("Vector",chartPanel) ;
		    }
		else if(i==ConstDeviationRenderer)
		    {
			onglets.add("Deviation",chartPanel) ;
		    }
		else if(i==ConstCyclicXYItemRenderer)
		    {
			onglets.add("Cyclic",chartPanel) ;
		    }
		else if(i==ConstClusteredXYBarRenderer)
		    {
			onglets.add("ClusteredBar",chartPanel) ;
		    }
		else if(i==ConstXYAreaRenderer)
		    {
			onglets.add("Area",chartPanel) ;
		    }
		else if(i==ConstXYAreaRenderer2)
		    {
			onglets.add("Area2",chartPanel) ;
		    }
		else if(i==ConstXYStepRenderer)
		    {
			onglets.add("Step",chartPanel) ;
		    }
		else if(i==ConstXYStepAreaRenderer)
		    {
			onglets.add("StepArea",chartPanel) ;
		    }
		else
		    {
			onglets.add("Standard",chartPanel) ;
		    }
		
		_plotList[i] = plot;
	    }
	
	content.add(onglets, BorderLayout.NORTH);


        final JPanel buttonPanel1 = new JPanel(new FlowLayout());
        
        for (int i = 0; i < _nbSubplots; i++) {
            final JButton buttonRun = new JButton("Run " + i);
            buttonRun.setActionCommand("RUN" + i);
            buttonRun.addActionListener(this);
            buttonPanel1.add(buttonRun);
        }

	final JButton buttonRunAll = new JButton("Run All ");
	buttonRunAll.setActionCommand("RUNALL");
	buttonRunAll.addActionListener(this);
	buttonPanel1.add(buttonRunAll);
	
        final JButton buttonConf = new JButton("Conf");
        buttonConf.setActionCommand("CONF");
        buttonConf.addActionListener(this);
        buttonPanel1.add(buttonConf);
        
        content.add(buttonPanel1, BorderLayout.CENTER);

        final JPanel buttonPanel2 = new JPanel(new FlowLayout());
        
        for (int i = 0; i < _nbSubplots; i++) {
            final JButton buttonClear = new JButton("clear " + i);
            buttonClear.setActionCommand("CLEAR" + i);
            buttonClear.addActionListener(this);
            buttonPanel2.add(buttonClear);
        }

	final JButton buttonClearAll = new JButton("Clear All ");
	buttonClearAll.setActionCommand("CLEARALL");
	buttonClearAll.addActionListener(this);
	buttonPanel2.add(buttonClearAll);
	
	final JButton buttonExit = new JButton("Exit");
        buttonExit.setActionCommand("EXIT");
        buttonExit.addActionListener(this);
        buttonPanel2.add(buttonExit);
        
        content.add(buttonPanel2, BorderLayout.SOUTH);

	setContentPane(content);
    }
    

    /**
     * Initialyze the Configuration Menu
     *     
     */            
    private void initConfMenu()
    {
	JFrame.setDefaultLookAndFeelDecorated(true);
		
	_frameConfiguration.getContentPane().setLayout(new BoxLayout(_frameConfiguration.getContentPane(), BoxLayout.X_AXIS));		
	_frameConfiguration.getContentPane().add(new MainConfiguration("Main Config ",_labelX));
		
	for (int i=0; i < _nbSubplots; i++)
	    {		
		JFrame mainFrame = new JFrame("plotConfiguration");
		_frameConfiguration.getContentPane().add(new PlotConfiguration("Config ",i, datasetColumnListX, datasetColumnListY, _datasetFile, _labelY));   
	    }
	
	_ConfMenuIsOpened = false;
	_frameConfiguration.setVisible(false);	
	_frameConfiguration.pack();
    }


    /**
     * Display/hide the Configuration Menu
     *
     */        
    private void showConfMenu()
    {
	if(!_ConfMenuIsOpened)
	    {	
		_frameConfiguration.setVisible(true);			
		_ConfMenuIsOpened = true;
	    }
	
	else
	    {
		_ConfMenuIsOpened = false;
		_frameConfiguration.setVisible(false);	
	    }
    }
    
    
    /**
     * Plot Creation with _nbSuplots
     *
     * @param subPlotType : subplotType for renderer
     */        
    private CombinedDomainXYPlot createPlot(int subPlotType)
    {
	final CombinedDomainXYPlot plot = new CombinedDomainXYPlot(new NumberAxis("X"));
	
	for (int i = 0; i < _nbSubplots; i++) {

            final NumberAxis rangeAxis = new NumberAxis("Y" + i);
	    final XYPlot subplot;

	    if(subPlotType == ConstDefaultXYItemRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new DefaultXYItemRenderer());
		    /*
		      default renderer for the XYPlot class. This is an alias for the XYLineAndShapeRenderer class.
		    */
		}
	    
	    else if(subPlotType == ConstXYLine3DRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new XYLine3DRenderer());
		    /*
		      A XYLineAndShapeRenderer that adds a shadow line to the graph to emulate a 3D-effect.
		    */
		}
    
	    else if(subPlotType == ConstXYSplineRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new XYSplineRenderer());		   		      
		}
	    
	    else if(subPlotType == ConstYIntervalRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new YIntervalRenderer());
		    /*
		      A renderer that draws a line connecting the start and end Y values for an XYPlot .
		    */
		}

	    else if(subPlotType == ConstXYDifferenceRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new XYDifferenceRenderer());
		    /*
		      A renderer for an XYPlot that highlights the differences between two series. The renderer expects a dataset that:
		      - has exactly two series;
		      - each series has the same x-values;
		      - no null values; 
		    */
		}

	    else if(subPlotType == ConstXYDotRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new XYDotRenderer());
		    /*
		      A renderer that draws a small dot at each data point for an XYPlot .
		    */
		}

	    else if(subPlotType == ConstXYErrorRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new XYErrorRenderer());
		    
		}

	    else if(subPlotType == ConstVectorRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new VectorRenderer());
		    
		}

	    else if(subPlotType == ConstDeviationRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new DeviationRenderer());
		}

	    else if(subPlotType == ConstCyclicXYItemRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new CyclicXYItemRenderer());
		    /*
		      The Cyclic XY item renderer is specially designed to handle cyclic axis. While the standard renderer would
		      draw a line across the plot when a cycling occurs, the cyclic renderer splits the line at each cycle end instead.
		      This is done by interpolating new points at cycle boundary. Thus, correct appearance is restored. 
		      The Cyclic XY item renderer works exactly like a standard XY item renderer with non-cyclic axis.
		    */
		}

	    else if(subPlotType == ConstClusteredXYBarRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new ClusteredXYBarRenderer());
		    /*
		      An extension of XYBarRenderer that displays bars for different series values at the same x next 
		      to each other. The assumption here is that for each x (time or else) there is a y value for each 
		      series. If this is not the case, there will be spaces between bars for a given x.
		      This renderer does not include code to calculate the crosshair point for the plot.
		    */
		}

	    else if(subPlotType == ConstXYAreaRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new XYAreaRenderer());
		    /*
		      Area item renderer for an XYPlot . This class can draw (a) shapes at each point, or (b) 
		      lines between points, or (c) both shapes and lines, or (d) filled areas, or (e) filled areas and shapes.
		    */
		}

	    else if(subPlotType == ConstXYAreaRenderer2)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new XYAreaRenderer2());
		    /* 
		       Area item renderer for an XYPlot .
		    */
		}

	    else if(subPlotType == ConstXYStepRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new XYStepRenderer());
		    /*
		      Line/Step item renderer for an XYPlot . This class draws lines between data points, only allowing horizontal or 
		      vertical lines (steps).
		    */
		}
	  
	    else if(subPlotType == ConstXYStepAreaRenderer)
		{
		    subplot = new XYPlot(this._datasets[i],  null, rangeAxis , new XYStepAreaRenderer());
		    /*
		      A step chart renderer that fills the area between the step and the x-axis.
		    */		    
		}	  
	   
	    else
		{
		    subplot = new XYPlot(this._datasets[i], null, rangeAxis, new StandardXYItemRenderer());
		    /*
		      Standard item renderer
		    */
		}		

	    _subplotList[subPlotType][i] = subplot;
	    
	    subplot.setBackgroundPaint(Color.lightGray);
	    subplot.setDomainGridlinePaint(Color.white);
	    subplot.setRangeGridlinePaint(Color.white);
          
	    plot.setBackgroundPaint(Color.lightGray);
	    plot.setDomainGridlinePaint(Color.white);
	    plot.setRangeGridlinePaint(Color.white);
	    final ValueAxis axis = plot.getDomainAxis();
	    axis.setAutoRange(true);
 
	    plot.add(subplot);	    
	}

	return plot;
    }

   
    /**
     * Handles a click on the Conf/Exit/Clear/Clear All/Run/Run All buttons.
     *
     * @param e  the action event.
     */
    public void actionPerformed(final ActionEvent e) {
	
	if (e.getActionCommand().equals("CONF")) 
	    {		
		showConfMenu();	    
	    }

	else if (e.getActionCommand().equals("EXIT")) 
	    {
		System.exit(0);
	    }

	else if (e.getActionCommand().equals("CLEARALL")) 
	    {
		for (int i = 0; i < _nbSubplots; i++) 
		    {						
			this._datasets[i].removeAllSeries();
			for(int j = 0; j < _nbPlots; j++)
			    {
				_subplotList[j][i].getRangeAxis().setLabel("Y" + i);
			    }
		    }

		for(int i =0; i< _nbPlots; i++)
		    {
			_plotList[i].getDomainAxis().setLabel("X");
		    }			
	    }

	else if (e.getActionCommand().startsWith("CLEAR")) 
	    {
		int plotNum = Integer.valueOf(e.getActionCommand().substring(5)).intValue();
		this._datasets[plotNum].removeAllSeries();
		for(int i = 0; i < _nbPlots; i++)
		    {
			_subplotList[i][plotNum].getRangeAxis().setLabel("Y" + plotNum);
		    }				
	    }

	else if (e.getActionCommand().equals("RUNALL")) 
	    {
	
		if(!_labelX[0].trim().equals(""))
		    {
			for(int i =0; i< _nbPlots; i++)
			    {
				_plotList[i].getDomainAxis().setLabel(_labelX[0]);
			    }
		    }
		else
		    {
			for(int i =0; i< _nbPlots; i++)
			    {
				_plotList[i].getDomainAxis().setLabel("X");
			    }			
		    }

		for (int i = 0; i < _nbSubplots; i++) 
		    {			
			if(!_labelY[i].trim().equals(""))
			    {
				for(int k = 0; k < _nbPlots; k++)
				    {
					_subplotList[k][i].getRangeAxis().setLabel(_labelY[i]);
				    }
			    }
			
			else 
			    {
				for(int k = 0; k < _nbPlots; k++)
				    {
					_subplotList[k][i].getRangeAxis().setLabel("Y" + i);
				    }

			    }
			
			this._datasets[i].removeAllSeries();			
			if(!_datasetFile[i].equals(""))
			    {
				this._datasets[i].removeAllSeries();
				int colX = datasetColumnListX[i].get(0).getColumn();
			
				for(int j= 0; j < datasetColumnListY[i].size(); j++)
				    {
					int colY = datasetColumnListY[i].get(j).getColumn();
					final XYSeries serie;
					String strSerie = "";
					
					if (!datasetColumnListY[i].get(j).isTitleEmpty())
					    {
						strSerie = datasetColumnListY[i].get(j).getTitle();
						serie = new XYSeries(strSerie);
						this._datasets[i].addSeries(serie);					
					    }
					
					else
					    {
						strSerie = String.valueOf(i) + "." + String.valueOf(j);
						serie = new XYSeries(strSerie);
						this._datasets[i].addSeries(serie);				
					    }

													
					// Read the Text File	
					try{
					    InputStream ips=new FileInputStream(_datasetFile[i]); 
					    InputStreamReader ipsr=new InputStreamReader(ips);
					    BufferedReader br=new BufferedReader(ipsr);
					    String ligne;
					    String [] content;

					    while ((ligne=br.readLine())!=null)
						{
						    if(!ligne.trim().equals(""))
							{
							    content = ligne.split("\\s+");		    
							    if(((content.length < colX +1) || (content.length < colY +1)) && (content.length > 0)) 
								{
								    System.out.println("Error : Bad column definition for <" + _datasetFile[i] + "> in Plots Group Config " + i + " or invalid line in the File");  
								}
							    else
								{							
								    this._datasets[i].getSeries(strSerie).add(Float.valueOf(content[colX]),Float.valueOf(content[colY]));    					
								}
							}
						}
					    ips.close();
					}						    	
					catch (Exception ex){
					    System.out.println("Error : Cannot Read File <" + _datasetFile[i] + "> needed for Plots Group " + i);   
					}
				    }
			    }
		    }	       
	    }
	
	else if (e.getActionCommand().startsWith("RUN")) 
	    {	 
		int plotNum = Integer.valueOf(e.getActionCommand().substring(3)).intValue();

		if(!_labelX[0].trim().equals(""))
		    {			
			for(int i =0; i< _nbPlots; i++)
			    {
				_plotList[i].getDomainAxis().setLabel(_labelX[0]);
			    }
		    }

		
		if(!_labelY[plotNum].trim().equals(""))
		    {
			for(int j = 0; j < _nbPlots; j++)
			    {
				_subplotList[j][plotNum].getRangeAxis().setLabel(_labelY[plotNum]);
			    }
		    }

		else
		    {
			for(int j = 0; j < _nbPlots; j++)
			    {
				_subplotList[j][plotNum].getRangeAxis().setLabel("Y" + plotNum);
			    }

		    }
			

		if(!_datasetFile[plotNum].equals(""))
		    {			
			this._datasets[plotNum].removeAllSeries();

			int colX = datasetColumnListX[plotNum].get(0).getColumn();

			for(int i= 0; i < datasetColumnListY[plotNum].size(); i++)
			    {
				int colY = datasetColumnListY[plotNum].get(i).getColumn();

				final XYSeries serie;
				String strSerie = "";

				if (!datasetColumnListY[plotNum].get(i).isTitleEmpty())
				    {
					strSerie = datasetColumnListY[plotNum].get(i).getTitle();
					serie = new XYSeries(strSerie);
					this._datasets[plotNum].addSeries(serie);					
				    }

				else
				    {
					strSerie = String.valueOf(plotNum) + "." + String.valueOf(i);
					serie = new XYSeries(strSerie);
					this._datasets[plotNum].addSeries(serie);				
				    }

								
				// Read the Text File	
				try{
				    InputStream ips=new FileInputStream(_datasetFile[plotNum]); 
				    InputStreamReader ipsr=new InputStreamReader(ips);
				    BufferedReader br=new BufferedReader(ipsr);
				    String ligne;
				    String [] content;

				    while ((ligne=br.readLine())!=null){
					if(!ligne.trim().equals(""))
					    {
						content = ligne.split("\\s+");		    
						if(((content.length < colX +1) || (content.length < colY +1)) && (content.length > 0)) 
						    {
							System.out.println("Error : Bad column definition for <" + _datasetFile[plotNum] + "> in Plots Group Config " + plotNum + " or invalid line in the File");  
						    }
						else
						    {
							this._datasets[plotNum].getSeries(strSerie).add(Float.valueOf(content[colX]),Float.valueOf(content[colY]));    					
						    }
					    }
				    }
				    ips.close();
				}		
				catch (Exception ex){
				    System.out.println("Error : Cannot Read File <" + _datasetFile[plotNum] + "> needed for Plots Group " + plotNum);  
				}
			    }
		    }

		else
		    {			
			System.out.println("Error : No File defined for Plots Group " + plotNum);  
		    }
	    }
    }


    /**
     * Starting point for JQuickPlot.
     *
     * @param  args <br/>
     * args[0] - NbGraphs (integer) : Graphs number (One Graph may contains several plots) <br/>
     * args[1] - Title (String)) : Main title
     */
    public static void main(final String[] args) 
    {
	if (args.length == 2)
	    {
		try
		    {
			final JQuickPlot startJQuickPlot = new JQuickPlot(Integer.valueOf(args[0]).intValue(),args[1]);
			startJQuickPlot.pack();
			RefineryUtilities.centerFrameOnScreen(startJQuickPlot);        
			startJQuickPlot.setVisible(true);
		    }
		
		catch (Exception ex){
		    JQuickPlot.usage();
		}
	    }

	else
	    JQuickPlot.usage();

    }


}