/**###########################################################################
   ##                                                                          ##
   ## JQuickPlot - Java Quick XY Plots                                         ##
   ##                                                                          ##
   ## Copyright (C) 2008  Frederic Roudaut  <frederic.roudaut@free.fr>         ##
   ##                                                                          ##
   ##                                                                          ##
   ## This program is free software; you can redistribute it and/or modify it  ##
   ## under the terms of the GNU General Public License version 2 as           ##
   ## published by the Free Software Foundation; version 2.                    ##
   ##                                                                          ##
   ## This program is distributed in the hope that it will be useful, but      ##
   ## WITHOUT ANY WARRANTY; without even the implied warranty of               ##
   ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU        ##
   ## General Public License for more details.                                 ##
   ##                                                                          ##
   ############################################################################**/

package JQuickPlot;

import org.jdesktop.layout.GroupLayout;
import org.jdesktop.layout.*;
import javax.swing.*;
import java.awt.event.*;
import java.awt.*;
import java.io.*;

/**
 * The Class used for the global plots configuration. Each plot may contains several subplot (ie graph) that may contain several curves.
 *
 */
public class MainConfiguration extends JPanel  implements ActionListener {

    private JToggleButton invokePopupButton;
    private JFrame curveConfMenu;
    private JTextField textFieldX = new JTextField();
    private String _plotRefName = "";
    private String []_labelX;

    
    /**
     * Constructor.
     *
     * @param plotRefName : Name to reference the subplot
     * @param labelX  : Reference on the X column to use for the plot
     **/
    public MainConfiguration(String plotRefName, String []labelX) {
	_plotRefName = plotRefName;
	_labelX = labelX;
	init();
    }
    

    /**
     * Initialiser for the Main configuration Menu.
     */
    private void init() {
	
        invokePopupButton = new JToggleButton(_plotRefName);
        invokePopupButton.addActionListener(new ActionListener() {
		
		public void actionPerformed(ActionEvent e) {
		    
		    if (!curveConfMenu.isVisible()) {
			
			// set location relative to button
			Point location = invokePopupButton.getLocation();
			SwingUtilities.convertPointToScreen(location, invokePopupButton.getParent());
			location.translate(0, invokePopupButton.getHeight()
					   + (invokePopupButton.getBorder() == null ? 0
					      : invokePopupButton.getBorder().getBorderInsets(invokePopupButton).bottom));
			curveConfMenu.setLocation(location);
			
			// show the popup if not visible
			curveConfMenu.setVisible(true);
			curveConfMenu.requestFocus();
		    } 
		    
		    else {
			// hide it otherwise
			curveConfMenu.setVisible(false);
			curveConfMenu.requestFocus();
		    }
		}
	    }
	    );
	
        // add components to main panel
        this.setLayout(new BorderLayout());
        this.add(invokePopupButton, BorderLayout.CENTER);
	
        // use frame
        curveConfMenu = new JFrame("[=] Main Configuration [=]");
	
	// Construction of the Options Panel
	JLabel labelInfo1 = new JLabel("JQuickPlot v0.9 - Java Quick XY Plots");
	JLabel labelInfo2 = new JLabel("Copyright (C) 2008  Frederic Roudaut  <frederic.roudaut@free.fr>");
	JLabel labelX = new JLabel("X Label");
	textFieldX.setColumns(20);
	
	JButton buttonSave = new JButton("Save");
	buttonSave.setActionCommand("SAVE");
        buttonSave.addActionListener(this);       

	JButton buttonClose = new JButton("Close");
	buttonClose.setActionCommand("CLOSE");
        buttonClose.addActionListener(this);       

        GroupLayout layout = new GroupLayout(curveConfMenu.getContentPane());
        curveConfMenu.getContentPane().setLayout(layout);
        layout.setAutocreateGaps(true);
        layout.setAutocreateContainerGaps(true);
	
        layout.setHorizontalGroup(layout.createParallelGroup()
				  .add(layout.createParallelGroup()		       
				       .add(labelInfo1)
				       .add(labelInfo2)
				       )
				  .add(layout.createSequentialGroup()		       
				       
				       .add(layout.createParallelGroup(GroupLayout.LEADING)
					    .add(labelX)
					    )
				       
				       .add(layout.createParallelGroup(GroupLayout.CENTER)
					    .add(textFieldX)
					    .add(layout.createSequentialGroup()
						 .add(buttonSave)
						 .add(buttonClose)
						 )
					    )				  
				       )
				  );
       
        layout.setVerticalGroup(layout.createSequentialGroup()
				.add(labelInfo1)
				.add(labelInfo2)
				.add(layout.createParallelGroup(GroupLayout.BASELINE)
				     .add(labelX)
				     .add(textFieldX)
				     )
				.add(layout.createParallelGroup(GroupLayout.LEADING)
				     .add(buttonSave)
				     .add(buttonClose)
				     )
				);
        curveConfMenu.pack();
    }
        
    
    /**
     * Handles a click on the Save/Close buttons.
     *
     * @param e  the action event.
     */   
    public void actionPerformed(ActionEvent e) {
	
	if (e.getActionCommand().equals("CLOSE")) {		    
	    curveConfMenu.setVisible(false);				
	}

	else if (e.getActionCommand().equals("SAVE")) {	
	    _labelX[0] = textFieldX.getText();
	    curveConfMenu.setVisible(false);				
	}
    }  
}
