/**###########################################################################
##                                                                          ##
## JQuickPlot - Java Quick XY Plots                                         ##
##                                                                          ##
## Copyright (C) 2008  Frederic Roudaut  <frederic.roudaut@free.fr>         ##
##                                                                          ##
##                                                                          ##
## This program is free software; you can redistribute it and/or modify it  ##
## under the terms of the GNU General Public License version 2 as           ##
## published by the Free Software Foundation; version 2.                    ##
##                                                                          ##
## This program is distributed in the hope that it will be useful, but      ##
## WITHOUT ANY WARRANTY; without even the implied warranty of               ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU        ##
## General Public License for more details.                                 ##
##                                                                          ##
############################################################################**/

package JQuickPlot;

import org.jdesktop.layout.GroupLayout;
import org.jdesktop.layout.*;
import javax.swing.*;
import java.awt.event.*;
import java.awt.*;
import java.io.*;


/**
 * The Class used to configure subplots. Each plot may contains several subplot (ie graph) that may contain several curves.
 *
 */
public class PlotConfiguration extends JPanel  implements ActionListener {

    private JToggleButton invokePopupButton;
    private JFrame curveConfMenu;
    private JTextField _textFieldFile = new JTextField();
    private JTextField _textFieldX = new JTextField();
    private JTextField _textFieldY = new JTextField();
    private JTextField _textFieldLabelY = new JTextField();
    private String _plotRefName = "";
    private int _plotRefNum = -1;
    private ColumnList[] _datasetColumnListX;
    private ColumnList[] _datasetColumnListY;
    private String [] _datasetFile; 
    private String [] _labelY; 

    /**
     * Constructor.
     *
     * @param plotRefName : Name to reference the subplot
     * @param plotRefNum  : Number to reference the subplot
     * @param datasetColumnListX : Reference on the X columns to use for the subplots
     * @param datasetColumnListY : Reference on the Y columns to use for the subplots
     * @param datasetFile : Reference on the dots Files for the subplots
     **/
    public PlotConfiguration(String plotRefName, int plotRefNum, ColumnList[] datasetColumnListX, ColumnList[] datasetColumnListY, String [] datasetFile, String [] labelY ) {
	_plotRefName = plotRefName;
	_plotRefNum = plotRefNum;
	_datasetColumnListX = datasetColumnListX;
	_datasetColumnListY = datasetColumnListY;
	_datasetFile = datasetFile;
	_labelY = labelY;
        init();
    }
    

    /**
     * Initialiser for the Plot configuration Menu.
     */
    private void init() {
	
        invokePopupButton = new JToggleButton(_plotRefName + _plotRefNum);
        invokePopupButton.addActionListener(new ActionListener() {
		
		public void actionPerformed(ActionEvent e) {
		    
		    if (!curveConfMenu.isVisible()) {
			
			// set location relative to button
			Point location = invokePopupButton.getLocation();
			SwingUtilities.convertPointToScreen(location, invokePopupButton.getParent());
			location.translate(0, invokePopupButton.getHeight()
					   + (invokePopupButton.getBorder() == null ? 0
					      : invokePopupButton.getBorder().getBorderInsets(invokePopupButton).bottom));
			curveConfMenu.setLocation(location);
			
			// show the popup if not visible
			curveConfMenu.setVisible(true);
			curveConfMenu.requestFocus();
		    } 
		    
		    else {
			// hide it otherwise
			curveConfMenu.setVisible(false);
			curveConfMenu.requestFocus();
		    }
		}
	    }
	    );
	
        // add components to main panel
        this.setLayout(new BorderLayout());
        this.add(invokePopupButton, BorderLayout.CENTER);
	
        // use frame
        curveConfMenu = new JFrame("[=] Configuration Graph " + _plotRefNum + " [=]");
	
	// Construction of the Options Panel
	JLabel labelFile = new JLabel("File");
	JLabel labelX = new JLabel("X");
	JLabel labelY = new JLabel("Y");
	JLabel labelLabelY = new JLabel("Y Label");
	_textFieldFile.setColumns(20);
	_textFieldX.setColumns(20);
	_textFieldY.setColumns(20);
	_textFieldLabelY.setColumns(20);
        JButton buttonRun = new JButton("Save");
	buttonRun.setActionCommand("SAVE");
        buttonRun.addActionListener(this);       
	JButton buttonClose = new JButton("Close");
	buttonClose.setActionCommand("CLOSE");
        buttonClose.addActionListener(this);       
        JButton buttonFile = new JButton("File");
	buttonFile.setActionCommand("SET_FILE");
        buttonFile.addActionListener(this);       

        GroupLayout layout = new GroupLayout(curveConfMenu.getContentPane());
        curveConfMenu.getContentPane().setLayout(layout);
        layout.setAutocreateGaps(true);
        layout.setAutocreateContainerGaps(true);
	
        layout.setHorizontalGroup(layout.createSequentialGroup()
				  .add(layout.createParallelGroup(GroupLayout.LEADING)
				       .add(labelLabelY)
				       .add(labelFile)
				       .add(labelX)
				       .add(labelY)				  
				       )
				  
				  .add(layout.createParallelGroup(GroupLayout.CENTER)
				       .add(_textFieldLabelY)
				       .add(_textFieldFile)
				       .add(_textFieldX)
				       .add(_textFieldY)
				       .add(layout.createSequentialGroup()
					    .add(buttonRun)
					    .add(buttonClose)
					    )
				       )
				  
				  .add(layout.createParallelGroup(GroupLayout.LEADING)
				       .add(buttonFile)
				       )
				  );
       
        layout.setVerticalGroup(layout.createSequentialGroup()
				.add(layout.createParallelGroup(GroupLayout.LEADING)
				     .add(labelLabelY)				     
				     .add(_textFieldLabelY)
				     )
				.add(layout.createParallelGroup(GroupLayout.BASELINE)
				     .add(labelFile)
				     .add(_textFieldFile)
				     .add(buttonFile)
				     )
				.add(layout.createParallelGroup(GroupLayout.LEADING)
				     .add(labelX)
				     .add(_textFieldX)
				     )
				.add(layout.createParallelGroup(GroupLayout.LEADING)
				     .add(labelY)
				     .add(_textFieldY)
				     )
				.add(layout.createParallelGroup(GroupLayout.LEADING)
				     .add(layout.createParallelGroup(GroupLayout.LEADING)
					  .add(buttonRun)
					  .add(buttonClose)
					  )
				     )
				);
        curveConfMenu.pack();
    }
    
    
    /**
     * Handles a click on the Save/Close buttons.
     *
     * @param e  the action event.
     */   
    public void actionPerformed(ActionEvent e) {
	
	if (e.getActionCommand().equals("SAVE")) {	
	    
	    _datasetFile[_plotRefNum] = _textFieldFile.getText();

	    ColumnList clX = ColumnList.parse(_textFieldX.getText());
	    if (clX.size() != 1)
		{
		    System.out.println("Error : Bad Syntax for X in <" + _plotRefName + _plotRefNum + ">");  		    
		}

	    _datasetColumnListX[_plotRefNum] = clX;

	    ColumnList clY = ColumnList.parse(_textFieldY.getText());
	    if (clY.size() < 1)
		{
		    System.out.println("Error : Bad Syntax for Y in <" + _plotRefName + _plotRefNum + ">");  		    
		}

	    _datasetColumnListY[_plotRefNum] = clY;

	    _labelY[_plotRefNum] = _textFieldLabelY.getText();


	    curveConfMenu.setVisible(false);				
	}
	
	else if (e.getActionCommand().equals("CLOSE")) {		    
	    curveConfMenu.setVisible(false);				
	}
	
	else if (e.getActionCommand().equals("SET_FILE")) 
	    {		    
		JFileChooser chooser = new JFileChooser();	    
		if (chooser.showOpenDialog(null) == JFileChooser.APPROVE_OPTION)
		    {
			_textFieldFile.setText(chooser.getSelectedFile().getAbsolutePath());			
		    }
	    }
    }

}
